# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['py_code_meli']

package_data = \
{'': ['*']}

install_requires = \
['pydantic>=1.8.2,<2.0.0', 'pytest>=6.2.5,<7.0.0']

setup_kwargs = {
    'name': 'py-code-meli',
    'version': '0.0.1',
    'description': 'This python package gives you a simple method that you can validate code meli (Iranian National Code) with it.',
    'long_description': None,
    'author': 'ali',
    'author_email': 'lmntrix.afr@gmail.com',
    'maintainer': None,
    'maintainer_email': None,
    'url': None,
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'python_requires': '>=3.8,<4.0',
}


setup(**setup_kwargs)
